	function [L, C, Rs, RL, W0, K] = CH_II_LADDER(G, Z, P, Wc, Ws, Rs, RL, Ladder)
	%
	%	Computes the element values for a doubly resistively
	%	terminated LC ladder of Chebyshev II type A and B.
	%
	%	Ladder = 1 for a T ladder and 0 for a  ladder
	%	Rs = source resistor and RL = load resistor
	%	K is a vector used by LADDER_2_H that defines the ladder 
	%	in terms of two-ports.
	%	
	%	Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009
	
	%
	% 	Author:			Lars Wanhammar, 2007-09-01
	% 	Modified by:	LW 2008-08-12
	%	Copyright:		Divison of Electronics Systems
	%					Dept. Electrical Engineering, Linkoping University, Sweden
	% 	Version:		1
	% 	Known bugs:		
	% 	Report bugs to:	larsw@isy.liu.se
	
	% Normalize the impedance level for improved accuracy
 
	R_ZEROS = zeros(1, length(P));	%	Reflection zeros
	[ZinNum, ZinDen] = ZIN_LADDER(R_ZEROS, Z, P, 1, RL/Rs);	%	Compute Zin
	[L, C, W0, K] = LP_LADDER(ZinNum, ZinDen, Z, P);
	if Ladder == 0
		[L, C, Rs, RL, K] = T_LADDER_2_PI(L, C, Rs, RL, K, Ladder);
	end
	L = L*Rs;		% Denormalize the element values
	C = C/Rs;
