	function [G, Z, P] = CH_I_POLES(Wc, Ws, Amax, Amin, N)
	%
	% 	Computes the denormalized poles, zeros and gain constant for  
	%	an analog lowpass Chebyshev I filter with |H(jw)|max = 1.
	%	The design margin is used to decrease the stopband edge.
	%
	% 	Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009
		
	% 	Author: 		Lars Wanhammar 1983-08-15
	% 	Modified by: 	LW,  1987-01-19, 2002-07-28, 2004-09-22
	% 	Copyright:		Divison of Electronics Systems
	% 					Dept. Electrical Engineering, Linkoping University, Sweden
	% 	Version:		1 
	% 	Known bugs:		None
	% 	Report bugs to:	larsw@isy.liu.se
	%
		if ~(abs(N-round(N)) < eps)
			N = floor(CH_ORDER(Wc, Ws, Amax, Amin)) + 1;
		end
		if (Wc >= Ws)
			error('Not a lowpass filter. Must have Wc < Ws')  
		elseif ( Amax <= 0 | Amax >= Amin)
			error('The passband attenuation must be 0 < Amax < Amin')
		elseif ( Amin <= 0)
			error('The stopband attenuation must be Amin > Amax > 0')
		end 
		odd = rem(N, 2);
		if odd == 1
			M = (N+1)/2; 
		else
			M = N/2;
		end
		Apn = Amax*log(10)/20;
		epsilon2 = 2*exp(Apn)*sinh(Apn);
		F = asinh(1/sqrt(epsilon2))/N;
		A = sinh(F); 
		B = cosh(F);
		Z = [];	% All zeros at s = oo
		P = [];
		% Compute the normalized poles
		for k = 1:M
			v = (2*k-1)*pi/(2*N);
			if k == M & odd == 1 	% real pole
				P = [-A*sin(v);P];
			else
				X = -A*sin(v) + i* B*cos(v);
				P = [conj(X);X;P];
			end
		end 
		% Denormalized the poles
		P = Wc*P;
		% Gain constant
		G = real(prod(-P));
		if (~rem(N, 2)) 	% N is even, hence correct the gain 
			G = G/sqrt(1 + epsilon2);
		end
		
		% The attenuation at the stopband edge is
		% W = Ws/Wc;
		% Tx = cosh(N*log10(W + sqrt(W*W-1)));
		% AstopEdge = 10*log10(1 + epsilon2*Tx*Tx);
