	function DELTA_AT = DELTA_ATTENUATION(tol, G, Z, P, W)
	%
	% 	Computes an upper bound on the variation in the attenuation 
	% 	due to tolerances, tol, in the reactive components in a
	% 	doubly resistively terminated reactance network.
	%
	%	Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009
		
	% 	Author: 		Lars Wanhammar 1986-9-27
	% 	Modified by: 	
	% 	Copyright:		Divison of Electronics Systems
	% 					Dept. Electrical Engineering, Linkoping University, Sweden
	% 	Version:		1
	% 	Known bugs:		
	% 	Report bugs to:	larsw@isy.liu.se
	%
	
	H = PZ_2_FREQ_S(G, Z, P, W);
	Hsquare = abs(H).^2+eps;
	Rsquare = sqrt(1 - Hsquare);
	Tg = PZ_2_TG_S(G, Z, P, W);
	DELTA_AT = 8.69*tol.*Rsquare.*W.*Tg./Hsquare;

