	function [Zodd, Podd, Zeven, Peven] = LATTICE_S(G, Z, P)
	%
	% 	Determines the reflectances S1 (odd) and S2 (even) in an analog lattice filter.
	%	The order must be odd for lowpass and highpass filters
	%
	%	Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009	
	
	% 	Author: 		Lars Wanhammar 2009-08-09
	% 	Modified by: 	 
	% 	Copyright:		Divison of Electronics Systems
	% 					Dept. Electrical Engineering, Linkoping University, Sweden
	% 	Version:		1 
	% 	Known bugs:		
	% 	Report bugs to:	larsw@isy.liu.se

	if mod(length(P), 2) ~= 1
		error('The order must be odd for lowpass and highpass filters')  
	end
	% Sort the poles into odd- and even-order branches
	N = length(P);
	P = cplxpair(P);
	Podd = P(N);
	Peven = [];
	m = 1;
	for k = 1:2:N-1	
		if mod(m,2) == 1
			Peven = [P(k); Peven];
			Peven = [P(k+1); Peven];
		else
			Podd = [P(k); Podd];
			Podd = [P(k+1); Podd];
		end
		m = m+1;
	end
	Podd = cplxpair(Podd);
	Zodd = -Podd;
	Peven = cplxpair(Peven);
	Zeven = -Peven;	
