	function [Ratio, Remaind] = LONG_DIV(P, Q)
	%
	%	Divides the polynomial P with Q and returns the polynomial, Ratio,
	%	and the numerator of the remainder, Remaind.
	% 	The polynomials have the highest power first.
	%
	% Toolbox for ANALOG FILTERS USING MATLAB, Springer, 2009
	
	% 	Author: 		Lars Wanhammar 2007-07-22
	%	 Modified by: 	 	
	%	 Copyright:		Divison of Electronics Systems
	% 					Dept. Electrical Engineering, Linkoping University, Sweden
	% 	Version:		1	
	% 	Known bugs:		
	% 	Report bugs to:	larsw@isy.liu.se
	
	NP = length(P);
	NQ = length(Q);
	k = NP-NQ+1;
	Ratio = zeros(1, k);
	R = P;
	for j = 1:k
		Ratio(j) = P(j)/Q(1);	
		y = zeros(1,k+1-j); y(1) = 1;
		R = POLYSUB(R, Ratio(j)*POLYMULT(Q, y));
	end
	for j = 1:NP-k
		Remaind(j) = R(j+k);
	end	
